fit.den.glm: Fit the density function for a generalized linear regression model.
Description
Fit the density function for a generalized linear regression model.
Usage
# S3 method for glm
fit.den(object, ...)
Value
the density function.
Arguments
- object
the fitted model.
- ...
other used arguments.