fit.den.lm: Fit the density function for a linear regression model.
Description
Fit the density function for a linear regression model.
Usage
# S3 method for lm
fit.den(object, ...)
Value
the density function.
Arguments
- object
the fitted model.
- ...
other used arguments.