Learn R Programming

em (version 1.0.0)

fit.den.multinom: Fit the density function for a multinomial regression model.

Description

Fit the density function for a multinomial regression model.

Usage

# S3 method for multinom
fit.den(object, ...)

Value

the density function.

Arguments

object

the fitted model.

...

other used arguments.