Learn R Programming

em (version 1.0.0)

fit.den.plm: Fit the density function for a panel regression model.

Description

Fit the density function for a panel regression model.

Usage

# S3 method for plm
fit.den(object, ...)

Value

the density function.

Arguments

object

the fitted model.

...

other used arguments.